@@ -27,7 +27,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *----------------------------------------------------------------------*/
 /*
-** $Id: init.c,v 1.159 2005/02/23 07:35:39 cvs Exp $
+** $Id: init.c,v 1.161 2005/04/19 06:31:17 cvs Exp $
 */
 
 #include "../config.h"
@@ -941,12 +941,6 @@ rxvt_init_resources(rxvt_t* r, int argc, const char *const *argv)
 
 	/* Initialize all atoms after establishing connection to X */
 	for (i = 0; i < NUM_XA; i++)	{
-#ifdef TRANSPARENT
-		/* do NOT set xa[XA_XROOTPMAPID] because it should only
-		** be set by rxvt_check_our_parents after the first vt
-		** is created! */
-		if (XA_XROOTPMAPID != i)
-#endif
 		r->h->xa[i] = XInternAtom(r->Xdisplay, xa_names[i], False);
 	}
 
@@ -2547,12 +2541,12 @@ rxvt_create_show_windows(rxvt_t* r, int argc, const char *const *argv)
 	** Now set window properties, like title, icon name and hints
 	*/
 	/* window title name */
-	win_prop.value = (char*) r->h->rs[Rs_title];
+	win_prop.value = (unsigned char*) r->h->rs[Rs_title];
 	win_prop.nitems = STRLEN (win_prop.value);
 	win_prop.encoding = XA_STRING;
 	win_prop.format = 8; 
 	/* icon name */
-	icon_prop.value = (char*) r->h->rs[Rs_iconName];
+	icon_prop.value = (unsigned char*) r->h->rs[Rs_iconName];
 	icon_prop.nitems = STRLEN (icon_prop.value);
 	icon_prop.encoding = XA_STRING;
 	icon_prop.format = 8; 
