@@ -11,7 +11,8 @@
  * Copyright (c) 1998-2001   Geoff Wing <gcw@pobox.com>
  * Copyright (c) 2000        Xianping Ge <xge@ics.uci.edu>
  * Copyright (c) 2003-2004   Marc Lehmann <pcg@goof.com>
- * Copyright (c) 2004        Jingmin Zhou <jimmyzhou@users.sourceforge.net>
+ * Copyright (c) 2005        Burgers A.R. <burgers@ecn.nl>
+ * Copyright (c) 2004-2005   Jingmin Zhou <jimmyzhou@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +29,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *----------------------------------------------------------------------*/
 /*
-** $Id: main.c,v 1.142 2005/02/23 07:36:20 cvs Exp $
+** $Id: main.c,v 1.144 2005/03/21 18:43:29 cvs Exp $
 */
 
 #include "../config.h"
@@ -410,6 +411,10 @@ rxvt_malloc(size_t size)
 {
 	void*		p;
 
+	/* see AC_FUNC_MALLOC macro in autoconf documentation */
+	if (0 == size)
+		size = 1;
+
 	p = malloc(size);
 	if (p)
 		return p;
@@ -1595,7 +1600,7 @@ rxvt_set_win_title (rxvt_t* r, Window win, const char* str)
 
 /* EXTPROTO */
 void
-rxvt_set_term_title (rxvt_t* r, const char *str)
+rxvt_set_term_title (rxvt_t* r, const unsigned char *str)
 {
 #ifdef SMART_WINDOW_TITLE
 	XTextProperty	prop;
@@ -1612,7 +1617,7 @@ rxvt_set_term_title (rxvt_t* r, const char *str)
 
 /* EXTPROTO */
 void
-rxvt_set_icon_name (rxvt_t* r, const char *str)
+rxvt_set_icon_name (rxvt_t* r, const unsigned char *str)
 {
 	XTextProperty	prop;
 
