@@ -22,7 +22,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *----------------------------------------------------------------------*/
 /*
-** $Id: protos.h,v 1.84 2005/01/14 21:51:00 cvs Exp $
+** $Id: protos.h,v 1.85 2005/03/21 00:42:08 cvs Exp $
 */
 
 #ifndef __PROTOS_H__
@@ -130,8 +130,8 @@ int              rxvt_init_font_xft               __PROTO((rxvt_t *r));
 int              rxvt_change_font_xft             __PROTO((rxvt_t* r, const char* fontname));
 #endif
 void             rxvt_set_win_title               __PROTO((rxvt_t* r, Window win, const char* str));
-void             rxvt_set_term_title              __PROTO((rxvt_t* r, const char* str));
-void             rxvt_set_icon_name               __PROTO((rxvt_t* r, const char* str));
+void             rxvt_set_term_title              __PROTO((rxvt_t* r, const unsigned char* str));
+void             rxvt_set_icon_name               __PROTO((rxvt_t* r, const unsigned char* str));
 void             rxvt_set_window_color            __PROTO((rxvt_t* r, int idx, const char* color));
 void             rxvt_recolour_cursor             __PROTO((rxvt_t *r));
 #ifdef XFT_SUPPORT
@@ -386,7 +386,7 @@ void             rxvt_kill_page                 __PROTO((rxvt_t* r, int page));
 void             rxvt_remove_page               __PROTO((rxvt_t* r, int page));
 void             rxvt_activate_page             __PROTO((rxvt_t* r, int page));
 void             rxvt_tabbar_set_visible_tabs   __PROTO((rxvt_t* r));
-void             rxvt_tabbar_set_title          __PROTO((rxvt_t* r, int page, const char TAINTED * str));
+void             rxvt_tabbar_set_title          __PROTO((rxvt_t* r, int page, const unsigned char TAINTED * str));
 void             rxvt_tabbar_resize             __PROTO((rxvt_t* r));
 void             rxvt_tabbar_dispatcher         __PROTO((rxvt_t* r, XButtonEvent* ev));
 int              rxvt_tabbar_visible            __PROTO((rxvt_t* r));
