@@ -6,7 +6,8 @@
  * Copyright (c) 1997-2001   Geoff Wing <gcw@pobox.com>
  * Copyright (c) 2003-2004   Marc Lehmann <pcg@goof.com>
  * Copyright (c) 2004        Terry Griffin <griffint@pobox.com>
- * Copyright (c) 2004        Jingmin Zhou <jimmyzhou@users.sourceforge.net>
+ * Copyright (c) 2005        Teun Burgers <burgers@ecn.nl>
+ * Copyright (c) 2004-2005   Jingmin Zhou <jimmyzhou@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +24,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *----------------------------------------------------------------------*/
 /*
-** $Id: rxvt.h,v 1.149 2005/02/23 08:21:44 cvs Exp $
+** $Id: rxvt.h,v 1.151 2005/03/21 00:42:08 cvs Exp $
 */
 
 #ifndef __RXVT_H__		/* include once only */
@@ -174,6 +175,10 @@
 # include <net/if_arp.h>
 #endif
 
+#ifdef HAVE_PTY_H
+# include <pty.h>
+#endif
+
 #ifdef OS_QNX
 # include <process.h>
 # include <sys/utsname.h>
@@ -342,6 +347,9 @@ typedef char*		XPointer;
 # ifdef OS_SOLARIS
 #  define LASTLOG_FILE		"/var/adm/lastlog"
 # endif
+# ifdef OS_OSF
+#  define LASTLOG_FILE		"/var/adm/lastlog"
+# endif
 # if !defined(LASTLOG_FILE) && defined(_PATH_LASTLOG)
 #  define LASTLOG_FILE     _PATH_LASTLOG
 # endif
