@@ -23,7 +23,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *----------------------------------------------------------------------*/
 /*
-** $Id: tabbar.c,v 1.122 2005/02/23 08:43:03 cvs Exp $
+** $Id: tabbar.c,v 1.123 2005/03/21 00:42:08 cvs Exp $
 */
 
 #include "../config.h"
@@ -1238,8 +1238,8 @@ rxvt_append_page (rxvt_t* r, const char TAINTED * title)
 		  (NULL == LVTS(r)->command_argv)))	{
 		const char*		cmd = r->h->rs[Rs_command+LTAB(r)];
 
-		rxvt_tt_write (r, LTAB(r), cmd, STRLEN(cmd));
-		rxvt_tt_write (r, LTAB(r), "\n", 1);
+		rxvt_tt_write (r, LTAB(r), (const unsigned char*) cmd, STRLEN(cmd));
+		rxvt_tt_write (r, LTAB(r), (const unsigned char*) "\n", 1);
 	}
 
 
@@ -1263,11 +1263,11 @@ rxvt_append_page (rxvt_t* r, const char TAINTED * title)
 
 	/* synchronize terminal title with tab title */
 	if (r->Options2 & Opt2_syncTabTitle)
-		rxvt_set_term_title (r, PVTS(r, ATAB(r))->tab_title);
+		rxvt_set_term_title (r, (const unsigned char*) PVTS(r, ATAB(r))->tab_title);
 
 	/* synchronize icon name to tab title */
 	if (r->Options2 & Opt2_syncTabIcon)
-		rxvt_set_icon_name (r, PVTS(r, ATAB(r))->tab_title);
+		rxvt_set_icon_name (r, (const unsigned char*) PVTS(r, ATAB(r))->tab_title);
 }
 
 
@@ -1363,11 +1363,11 @@ rxvt_remove_page (rxvt_t* r, int page)
 
 	/* synchronize terminal title with tab title */
 	if (r->Options2 & Opt2_syncTabTitle)
-		rxvt_set_term_title (r, PVTS(r, ATAB(r))->tab_title);
+		rxvt_set_term_title (r, (const unsigned char*) PVTS(r, ATAB(r))->tab_title);
 
 	/* synchronize icon name to tab title */
 	if (r->Options2 & Opt2_syncTabIcon)
-		rxvt_set_icon_name(r, PVTS(r, ATAB(r))->tab_title);
+		rxvt_set_icon_name(r, (const unsigned char*) PVTS(r, ATAB(r))->tab_title);
 }
 
 
@@ -1376,7 +1376,7 @@ rxvt_remove_page (rxvt_t* r, int page)
 */
 /* EXTPROTO */
 void
-rxvt_tabbar_set_title (rxvt_t* r, int page, const char TAINTED * str)
+rxvt_tabbar_set_title (rxvt_t* r, int page, const unsigned char TAINTED * str)
 {
 	char UNTAINTED *		n_title;
 
@@ -1409,12 +1409,12 @@ rxvt_tabbar_set_title (rxvt_t* r, int page, const char TAINTED * str)
 	/* synchronize terminal title with active tab title */
 	if ((r->Options2 & Opt2_syncTabTitle) &&
 		(page == ATAB(r)))
-		rxvt_set_term_title (r, PVTS(r, ATAB(r))->tab_title);
+		rxvt_set_term_title (r, (const unsigned char*) PVTS(r, ATAB(r))->tab_title);
 
 	/* synchronize icon name to tab title */
 	if ((r->Options2 & Opt2_syncTabIcon) &&
 		(page == ATAB(r)))
-		rxvt_set_icon_name(r, PVTS(r, ATAB(r))->tab_title);
+		rxvt_set_icon_name(r, (const unsigned char*) PVTS(r, ATAB(r))->tab_title);
 }
 
 
@@ -1475,11 +1475,11 @@ rxvt_activate_page (rxvt_t* r, int index)
 
 	/* synchronize terminal title with tab title */
 	if (r->Options2 & Opt2_syncTabTitle)
-		rxvt_set_term_title (r, PVTS(r, ATAB(r))->tab_title);
+		rxvt_set_term_title (r, (const unsigned char*) PVTS(r, ATAB(r))->tab_title);
 
 	/* synchronize icon name to tab title */
 	if (r->Options2 & Opt2_syncTabIcon)
-		rxvt_set_icon_name(r, PVTS(r, ATAB(r))->tab_title);
+		rxvt_set_icon_name(r, (const unsigned char*) PVTS(r, ATAB(r))->tab_title);
 }
 
 
