@@ -24,7 +24,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *----------------------------------------------------------------------*/
 /*
-** $Id: xdefaults.c,v 1.136 2005/02/23 08:21:44 cvs Exp $
+** $Id: xdefaults.c,v 1.139 2005/03/21 18:44:10 cvs Exp $
 */
 
 #include "../config.h"
@@ -725,13 +725,13 @@ rxvt_usage(int type)
 {
 	unsigned int	i, col;
 
-	write(STDERR_FILENO, releasestring, sizeof(releasestring) - 1);
-	write(STDERR_FILENO, optionsstring, sizeof(optionsstring) - 1);
-	write(STDERR_FILENO, APL_NAME, sizeof(APL_NAME) - 1);
+	write(STDOUT_FILENO, releasestring, sizeof(releasestring) - 1);
+	write(STDOUT_FILENO, optionsstring, sizeof(optionsstring) - 1);
+	write(STDOUT_FILENO, APL_NAME, sizeof(APL_NAME) - 1);
 
 	switch (type) {
 	case 0:			/* brief listing */
-		fprintf(stderr, " [-help] [--help]\n");
+		fprintf(stdout, " [-help] [--help]\n");
 		for (col = 1, i = 0; i < optList_size(); i++)
 			if (optList[i].desc != NULL) {
 				int			 len = 0;
@@ -747,26 +747,26 @@ rxvt_usage(int type)
 					(optList_isBool(i) ? 2: 0);
 				col += len;
 				if (col > 79) {	/* assume regular width */
-					putc('\n', stderr);
+					putc('\n', stdout);
 					col = 1 + len;
 				}
-				fprintf(stderr, " [-%s%s", (optList_isBool(i) ?
+				fprintf(stdout, " [-%s%s", (optList_isBool(i) ?
 					"/+" : ""), optList[i].opt);
 				if (optList_STRLEN(i))
-					fprintf(stderr, " %s]", optList[i].arg);
+					fprintf(stdout, " %s]", optList[i].arg);
 				else
-					fprintf(stderr, "]");
+					fprintf(stdout, "]");
 			}
 		break;
 
 	case 1:			/* full command-line listing */
-		fprintf(stderr, " [options] [-e command args]\n\n"
+		fprintf(stdout, " [options] [-e command args]\n\n"
 			"where options include:\n");
 		for (i = 0; i < optList_size(); i++)
 			if (optList[i].desc != NULL) {
 				assert(optList[i].opt != NULL);
 
-				fprintf(stderr, "  %s%s %-*s%s%s\n",
+				fprintf(stdout, "  %s%s %-*s%s%s\n",
 					(optList_isBool(i) ? "-/+" : "-"), optList[i].opt,
 					(INDENT - STRLEN(optList[i].opt)
 					 + (optList_isBool(i) ? 0 : 2)),
@@ -774,30 +774,30 @@ rxvt_usage(int type)
 					(optList_isBool(i) ? "turn on/off " : ""),
 					optList[i].desc);
 			}
-		fprintf(stderr, "\n  --help to list long-options");
+		fprintf(stdout, "\n  --help to list long-options");
 		break;
 
 	case 2:			/* full resource listing */
-		fprintf(stderr,
+		fprintf(stdout,
 			" [options] [-e command args]\n\n"
 			"where resources (long-options) include:\n");
 
 		for (i = 0; i < optList_size(); i++)
 			if (optList[i].kw != NULL)
-				fprintf(stderr, "  %s: %*s%s\n",
+				fprintf(stdout, "  %s: %*s%s\n",
 					optList[i].kw,
 					(INDENT - STRLEN(optList[i].kw)), "", /* XXX */
 					(optList_isBool(i) ? "boolean" : optList[i].arg));
 #ifdef KEYSYM_RESOURCE
-		fprintf(stderr, "  " "keysym.sym" ": %*s%s\n",
+		fprintf(stdout, "  " "keysym.sym" ": %*s%s\n",
 			(INDENT - sizeof("keysym.sym") + 1), "", /* XXX */
 			"keysym");
 #endif
-		fprintf(stderr, "\n  -help to list options");
+		fprintf(stdout, "\n  -help to list options");
 		break;
 	}	/* switch */
 
-	fprintf(stderr, "\n\n");
+	fprintf(stdout, "\n\n");
 	exit(EXIT_FAILURE);
 	/* NOTREACHED */
 }
@@ -1145,7 +1145,7 @@ rxvt_parse_keysym(rxvt_t *r, const char *str, const char *arg)
 
 	/* some scanf() have trouble with a 0x prefix */
 	if (isdigit((int) str[0])) {
-		if (str[0] == '0' && toupper(str[1]) == 'X')
+		if (str[0] == '0' && toupper((int) str[1]) == 'X')
 			str += 2;
 
 		if (arg) {
@@ -1226,7 +1226,7 @@ rxvt_parse_hotkeys (rxvt_t* r, int res, char* oldkeystr)
 	/* convert keystr to lower case */
 	keystr = STRDUP (oldkeystr);
 	for (ptr = keystr; *ptr; ptr++)
-		*ptr = (char) tolower (*ptr);
+		*ptr = (char) tolower ((int) *ptr);
 
 	if (NULL != STRSTR (keystr, "ctrl"))
 		HK_SET_CTRL (flag);
@@ -1466,14 +1466,14 @@ get_xdefault_resource(XrmDatabase database, const char *name, char *subClass, ch
 
 	/* allocate memory for str_class and str_name */
 	len = prefix_len + STRLEN(resource) + 2;
-	str_class = malloc(len);
-	str_name = malloc(len);
+	str_class = rxvt_malloc(len);
+	str_name = rxvt_malloc(len);
 
 	snprintf(str_name, len-1, "%s.%s", name, resource);
 	str_name[len-1] = (char) 0;
 
 	/* translate resource to class */
-	resourceClass = malloc(STRLEN(resource) + 1);
+	resourceClass = rxvt_malloc(STRLEN(resource) + 1);
 	resourceClass[0] = toupper(resource[0]);
 	for (i = 1; i < STRLEN(resource); i++) {
 		if (resource[i - 1] == '.') {
